pub enum HostedToolKind {
WebSearch,
}Expand description
Provider-neutral kind of tool executed by the model provider.
Variants
WebSearch
Searches the public web inside the provider response lifecycle.
Implementations