pub struct ModelRegistry { /* private fields */ }Expand description
Immutable reference registry for a fixed runtime provider generation.
Implementations
Sourceimpl ModelRegistry
impl ModelRegistry
Sourcepub fn new(
providers: impl IntoIterator<Item = Arc<dyn ModelProvider>>,
) -> Result<Self, ModelRegistryError>
pub fn new( providers: impl IntoIterator<Item = Arc<dyn ModelProvider>>, ) -> Result<Self, ModelRegistryError>
Builds a validated registry from one immutable provider generation.
Errors
Returns an error for duplicate provider identities or a provider that advertises a model owned by another provider.
Sourcepub fn provider_count(&self) -> usize
pub fn provider_count(&self) -> usize
Returns the registered provider count.
Sourcepub fn provider_ids(&self) -> Vec<ProviderId>
pub fn provider_ids(&self) -> Vec<ProviderId>
Returns registered provider identities in canonical order.