pub struct WebSearchLocation { /* private fields */ }Expand description
Bounded approximate user location for hosted web search.
Implementations
Sourceimpl WebSearchLocation
impl WebSearchLocation
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates an empty location that can be populated through validated builders.
Sourcepub fn with_country(
self,
country: impl Into<String>,
) -> Result<Self, ModelRequestError>
pub fn with_country( self, country: impl Into<String>, ) -> Result<Self, ModelRequestError>
Sets an ISO 3166-1 alpha-2 uppercase country code.
Errors
Returns an error when the value is not exactly two uppercase ASCII letters.
Sourcepub fn with_city(
self,
city: impl Into<String>,
) -> Result<Self, ModelRequestError>
pub fn with_city( self, city: impl Into<String>, ) -> Result<Self, ModelRequestError>
Sets a bounded city name.
Errors
Returns an error for empty, oversized, or control-containing text.
Sourcepub fn with_region(
self,
region: impl Into<String>,
) -> Result<Self, ModelRequestError>
pub fn with_region( self, region: impl Into<String>, ) -> Result<Self, ModelRequestError>
Sets a bounded region name.
Errors
Returns an error for empty, oversized, or control-containing text.
Sourcepub fn with_timezone(
self,
timezone: impl Into<String>,
) -> Result<Self, ModelRequestError>
pub fn with_timezone( self, timezone: impl Into<String>, ) -> Result<Self, ModelRequestError>
Sets a canonical IANA-style timezone name.
Errors
Returns an error for empty, oversized, or non-canonical text.